aboutsummaryrefslogtreecommitdiffstats
path: root/examples/charts/percentbarchart.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/charts/percentbarchart.py')
-rw-r--r--examples/charts/percentbarchart.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/examples/charts/percentbarchart.py b/examples/charts/percentbarchart.py
index 256070e7f..a70cae7cf 100644
--- a/examples/charts/percentbarchart.py
+++ b/examples/charts/percentbarchart.py
@@ -39,13 +39,13 @@
##
#############################################################################
"""PySide2 port of the Percent Bar Chart example from Qt v5.x"""
import sys
-from PySide2.QtCore import Qt
-from PySide2.QtGui import QPainter
-from PySide2.QtWidgets import (QMainWindow, QApplication)
-from PySide2.QtCharts import QtCharts
+from PySide6.QtCore import Qt
+from PySide6.QtGui import QPainter
+from PySide6.QtWidgets import (QMainWindow, QApplication)
+from PySide6.QtCharts import QtCharts
class MainWindow(QMainWindow):
def __init__(self):
@@ -39,13 +39,13 @@
##
#############################################################################
-"""PySide2 port of the Percent Bar Chart example from Qt v5.x"""
+"""PySide6 port of the Percent Bar Chart example from Qt v5.x"""
import sys